@@ -102,6 +102,10 @@ from alchemite_apiclient.model.get_suggest_initial_failed import GetSuggestIniti
 from alchemite_apiclient.model.get_suggest_initial_failed_all_of import GetSuggestInitialFailedAllOf
 from alchemite_apiclient.model.get_suggest_initial_pending import GetSuggestInitialPending
 from alchemite_apiclient.model.get_suggest_initial_running import GetSuggestInitialRunning
+from alchemite_apiclient.model.histogram_categorical import HistogramCategorical
+from alchemite_apiclient.model.histogram_continuous import HistogramContinuous
+from alchemite_apiclient.model.histogram_request import HistogramRequest
+from alchemite_apiclient.model.histogram_response import HistogramResponse
 from alchemite_apiclient.model.historic_categorical_prediction import HistoricCategoricalPrediction
 from alchemite_apiclient.model.historic_prediction import HistoricPrediction
 from alchemite_apiclient.model.historic_scalar_prediction import HistoricScalarPrediction
@@ -188,6 +192,11 @@ from alchemite_apiclient.model.part_tar_fn_sum import PartTarFnSum
 from alchemite_apiclient.model.part_tar_fn_weighted_sum import PartTarFnWeightedSum
 from alchemite_apiclient.model.predict_request import PredictRequest
 from alchemite_apiclient.model.prediction import Prediction
+from alchemite_apiclient.model.project import Project
+from alchemite_apiclient.model.project_bulk_model import ProjectBulkModel
+from alchemite_apiclient.model.project_bulk_suggest_initial import ProjectBulkSuggestInitial
+from alchemite_apiclient.model.project_patch import ProjectPatch
+from alchemite_apiclient.model.project_sharing import ProjectSharing
 from alchemite_apiclient.model.query_request import QueryRequest
 from alchemite_apiclient.model.query_response import QueryResponse
 from alchemite_apiclient.model.range import Range
@@ -219,6 +228,7 @@ from alchemite_apiclient.model.suggest_historic_parameters import SuggestHistori
 from alchemite_apiclient.model.suggest_historic_request import SuggestHistoricRequest
 from alchemite_apiclient.model.suggest_historic_result import SuggestHistoricResult
 from alchemite_apiclient.model.suggest_historic_result_samples import SuggestHistoricResultSamples
+from alchemite_apiclient.model.suggest_initial_job_patch import SuggestInitialJobPatch
 from alchemite_apiclient.model.suggest_initial_parameters import SuggestInitialParameters
 from alchemite_apiclient.model.suggest_initial_request import SuggestInitialRequest
 from alchemite_apiclient.model.suggest_initial_request_all_of import SuggestInitialRequestAllOf
